@@ -2,14 +2,14 @@ import ast
 
 from textx import metamodel_from_file
 
-from generators.expressions import Factor, UnaryOp, NotTest, \
+from pseutopy.generators.expressions import Factor, UnaryOp, NotTest, \
     BinaryOp, OrTest, AndTest, Comparison, TestList, Expr, XorExpr, AndExpr, \
     ShiftExpr, ArithExpr, Term, Power, TestListStarExpr, AtomExpr, Atom, \
     Parameters, TypedArgsList
-from generators.statements import Statement, ExprStmt, \
+from pseutopy.generators.statements import Statement, ExprStmt, \
     InputStmt, FuncCallStmt, DeclareStmt, PrintStmt, DelStmt, IfStmt, \
     WhileStmt, ForStmt, FuncDef, ReturnStmt
-from generators.values import Number, Name, String, NoneType, \
+from pseutopy.generators.values import Number, Name, String, NoneType, \
     Boolean
 
 
